//+------------------------------------------------------------------+
//|                                        OzFX smD1 iSignals v2.mq4 |
//|                                                         SwingMan |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008, SwingMan"
#property link      ""
//====================================================================
// HISTORY
// v1 - Source Code = OzFX Daily Signals X-02RR 
//                    #property copyright "Copyright  2008, DGC"
//                    #property link      "http://www.ozfx.com.au/"
//                  = Ronald Raygun codes  
// v2 - Alert options for RegularCode and AESCode
//    - TickValue and MarginRequired
//    - Check ShiftEntry only =0 or =1
//====================================================================

#property indicator_chart_window

#property indicator_buffers 6
#property indicator_color1 Blue  // EntryLong 1
#property indicator_color2 Red   // EntryShort 1
#property indicator_color3 Blue  // EntryLong 2
#property indicator_color4 Red   // EntryShort 2
#property indicator_color5 Green   // avg long
#property indicator_color6 Crimson // avg short

//---- extern inputs -------------------------------------------------
extern int ShiftEntry = 0;
extern int offsetArrows = 40;
extern bool SendAlert_RegularCode = false;
extern bool SendAlert_AESCode = false;
extern bool Show_TickValueAndMargin = false;
extern bool Show_BalanceLine = false;
//--------------------------------------------------------------------

//---- constants
int Period_avg = 5;
int Mode_avg = MODE_SMA;
int Price_avg =PRICE_TYPICAL;

//---- buffers
double OzFX_RegularLong[], OzFX_RegularShort[];
double OzFX_AESLong[], OzFX_AESShort[];
double avg[], avgLong[], avgShort[];
double trend[];

//---- variables
int iLastRegular;
double dLastAES;
int k;
string IndicatorName;


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   if (ShiftEntry < 0 || ShiftEntry > 1) {
     Alert("Allowed values for ShiftEntry are only 0 or 1.");
     return(-1); 
   }
   IndicatorName = "OzFX smD1 iSignals v2";   
   ShowResults();
//---- signals
   SetIndexBuffer(0, OzFX_RegularLong);
   SetIndexBuffer(1, OzFX_RegularShort);   
   SetIndexBuffer(2, OzFX_AESLong);     
   SetIndexBuffer(3, OzFX_AESShort);  
   
   SetIndexStyle(0,DRAW_ARROW,EMPTY,2);      
   SetIndexStyle(1,DRAW_ARROW,EMPTY,2);
   SetIndexStyle(2,DRAW_ARROW,EMPTY,2);      
   SetIndexStyle(3,DRAW_ARROW,EMPTY,2);
   
   SetIndexArrow(0, 233); // regular
   SetIndexArrow(1, 234);
   SetIndexArrow(2, 241); // AES
   SetIndexArrow(3, 242);
   
//---- mavg      
   ArraySetAsSeries(avg,true);
   ArraySetAsSeries(trend,true);
   
   SetIndexBuffer(4, avgLong);
   SetIndexBuffer(5, avgShort);

   if (Show_BalanceLine) {
      SetIndexStyle(4,DRAW_LINE,STYLE_SOLID,2);
      SetIndexStyle(5,DRAW_LINE,STYLE_SOLID,2);   
   } else {
      SetIndexStyle(4,DRAW_NONE);
      SetIndexStyle(5,DRAW_NONE);   
   }
//---- labels
   SetIndexLabel(0, NULL); // regular
   SetIndexLabel(1, NULL);
   SetIndexLabel(2, NULL); // AES
   SetIndexLabel(3, NULL);   
   SetIndexLabel(4, NULL);
   SetIndexLabel(5, NULL);   
   //---- or   
   /*SetIndexLabel(0, "LONG regular"); // regular
   SetIndexLabel(1, "SHORT regular");
   SetIndexLabel(2, "LONG AES"); // AES
   SetIndexLabel(3, "SHORT AES");   
   if (Show_BalanceLine) {   
      SetIndexLabel(4, "avgLong");
      SetIndexLabel(5, "avgShort");      
   } else {   
      SetIndexLabel(4, NULL);
      SetIndexLabel(5, NULL);   
   }*/
//----
   return(0);
}
  
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{  
   return(0);
}
  
  
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   if (ShiftEntry < 0 || ShiftEntry > 1) return(-1); 
   ArrayResize(avg,Bars);
   ArrayResize(trend,Bars);
   
   int    counted_bars=IndicatorCounted();
   if(counted_bars < 0) return(-1); 
   int limit=Bars-counted_bars;
//----
   //for (k = Bars - 205; k >= 0; k --)
   for (k = limit; k >= 0; k --)
   {

/*  OZFX REGULAR CODE  Yellow */
/*---------------------*/
      OzFX_RegularLong[k] = 0;
      OzFX_RegularShort[k] = 0;
      if (iAC(Symbol(), 0, k + ShiftEntry) > 0 &&
          iAC(Symbol(), 0, k + ShiftEntry) > iAC(Symbol(), 0, k + 1 + ShiftEntry) &&
          iStochastic(Symbol(), 0, 5, 3, 3, MODE_SMA, 0, MODE_MAIN, k + ShiftEntry) > 50)
      {
         if (iLastRegular != 1) {
            OzFX_RegularLong[k] = Low[k] - offsetArrows*Point;
            if (SendAlert_RegularCode && k == 0) Alert("LONG Signal for " + Symbol() + "  (OzFX regular code)");
         }   
         iLastRegular = 1;         
      }   
      
      if (iAC(Symbol(), 0, k + ShiftEntry) < 0 &&
          iAC(Symbol(), 0, k + ShiftEntry) < iAC(Symbol(), 0, k + 1 + ShiftEntry) &&
          iStochastic(Symbol(), 0, 5, 3, 3, MODE_SMA, 0, MODE_MAIN, k + ShiftEntry) < 50)
      {
         if (iLastRegular != -1) {
            OzFX_RegularShort[k] = High[k] + offsetArrows*Point;
            if (SendAlert_RegularCode && k == 0) Alert("SHORT Signal for " + Symbol() + "  (OzFX regular code)");
         }   
         iLastRegular = -1;   
      }   

/*  OZFX AES CODE  DodgerBlue */
/*-----------------*/
      OzFX_AESLong[k] = 0;
      OzFX_AESShort[k] = 0;
      if (iAC(Symbol(), 0, k + ShiftEntry) > iAC(Symbol(), 0, k + 1 + ShiftEntry) &&
          iStochastic(Symbol(), 0, 5, 3, 3, MODE_SMA, 0, MODE_MAIN, k + ShiftEntry)
          > iStochastic(Symbol(), 0, 5, 3, 3, MODE_SMA, 0, MODE_SIGNAL, k + ShiftEntry))
      {
         if (dLastAES != 0.7) {
            OzFX_AESLong[k] = Low[k] - offsetArrows*Point;         
            if (SendAlert_AESCode && k == 0) Alert("LONG Signal for " + Symbol() + "  (OzFX AES code)");
         }   
         dLastAES = 0.7;   
      }   
      
      if (iAC(Symbol(), 0, k + ShiftEntry) < iAC(Symbol(), 0, k + 1 + ShiftEntry) &&
          iStochastic(Symbol(), 0, 5, 3, 3, MODE_SMA, 0, MODE_MAIN, k + ShiftEntry)
          < iStochastic(Symbol(), 0, 5, 3, 3, MODE_SMA, 0, MODE_SIGNAL, k + ShiftEntry))
      {
         if (dLastAES != -0.7) {
            OzFX_AESShort[k] = High[k] + offsetArrows*Point;         
            if (SendAlert_AESCode && k == 0) Alert("LONG Signal for " + Symbol() + "  (OzFX AES code)");
         }   
         dLastAES = -0.7;
      }   
      
/*  average colored */
/*-----------------*/               
      avg[k] = iMA(Symbol(), 0, Period_avg, 0, Mode_avg, Price_avg, k);

        trend[k] = trend[k+1];
        if (avg[k]> avg[k+1]) trend[k] =1;
        if (avg[k]< avg[k+1]) trend[k] =-1;

      if (trend[k]>0)
        { 
          avgLong[k] = avg[k];       
          if (trend[k+1]<0) avgLong[k+1]=avg[k+1]; 
          avgShort[k] = EMPTY_VALUE;
        }
      else              
      {
      if (trend[k]<0)
        { 
          avgShort[k] = avg[k]; 
          if (trend[k+1]>0) avgShort[k+1]=avg[k+1];
          avgLong[k] = EMPTY_VALUE;
        }              
      }
   }   
//----
   return(0);
}
//+------------------------------------------------------------------+


//--------------------------------------------------------------------
//   Show Results
//--------------------------------------------------------------------
void ShowResults()
{    
   string st = IndicatorName;
   if (Show_TickValueAndMargin) {
   st = st +"\n";
   st = st + "*************************\n";   
   st = st + "TickValue = "  + DoubleToStr(MarketInfo(Symbol(),MODE_TICKVALUE),2)+"\n";   
   st = st + "MarginRequired = "  + DoubleToStr(MarketInfo(Symbol(),MODE_MARGINREQUIRED),0)+"\n";
   st = st + "*************************";
   }
   Comment(st);
}